@@ -17,24 +17,24 @@
 #ifndef XTRAZSTATUSACTION_H
 #define XTRAZSTATUSACTION_H
 
-#include <kaction.h>
+#include <QAction>
 
 #include "xtrazstatus.h"
 
 namespace Xtraz
 {
 
-class StatusAction: public KAction
+class StatusAction: public QAction
 {
 	Q_OBJECT
 public:
 	StatusAction( const Xtraz::Status &status, QObject *parent );
 
-public slots:
-	void triggered();
+public Q_SLOTS:
+	void slotTriggered(bool);
 
-signals:
-	void triggered( const Xtraz::Status &status );
+Q_SIGNALS:
+	void triggeredStatus( const Xtraz::Status &status );
 
 private:
 	Xtraz::Status mStatus;
